@@ -34,11 +34,7 @@ class BaseBundle(bundle.Bundle):
 
         d = src_dict.copy()
 
-        _Bundle_kwargs = super().from_dict(src_dict=d).to_dict()
-
-        base_bundle = cls(
-            **_Bundle_kwargs,
-        )
+        base_bundle = cls()
 
         base_bundle.additional_properties = d
         return base_bundle
