@@ -34,11 +34,7 @@ class Me(user.User):
 
         d = src_dict.copy()
 
-        _User_kwargs = super().from_dict(src_dict=d).to_dict()
-
-        me = cls(
-            **_User_kwargs,
-        )
+        me = cls()
 
         me.additional_properties = d
         return me
